@@ -227,8 +227,7 @@ has 'TableSpec' => ( is => 'ro', isa => 'RapidApp::TableSpec', lazy_build => 1 )
 sub _build_TableSpec {
   my $self = shift;
 
-  my $table = $self->ResultClass->table;
-  $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+  my $table = $self->ResultClass->_table_name_safe;
   my %opt = (
     name => $table,
     relation_sep => $self->relation_sep,
@@ -363,7 +362,7 @@ sub prepare_rest_request {
   # ---
   
   return unless defined $args[0];
-  my $key = lc("$args[0]");
+  my $key = "$args[0]";
   my $val = $args[1];
   
   # Ignore paths that are submodules or actions:
@@ -425,7 +424,14 @@ sub restGetRow {
 # object via arbitrary 'rs_method' path spec
 sub _resolve_rel_obj_method {
   my ($self, $rs_method) = @_;
-  my ($key,$val,$rel) = split('/',$rs_method,3);
+  
+  # New: Parse like this in case the middle $val contains '/'
+  my @parts = split('/',$rs_method);
+  my $key = shift @parts;
+  my $rel = pop @parts;
+  my $val = join('/',@parts);
+  #my ($key,$val,$rel) = split('/',$rs_method,3);
+  
   my $Row = $self->restGetRow($key,$val);
   die usererr "No such relationship $rel at ''$rs_method''" unless ($Row->has_relationship($rel));
   return wantarray ? (scalar $Row->$rel, $Row) : $Row->$rel;
@@ -801,11 +807,7 @@ sub rs_all {
   # it for sorting either. So we are falling back to the broadest compatability.
   # TODO: optimize cases for each different backend
   if(my $sels = $Rs->{attrs}{select}) {
-    @$sels = map { (
-      (ref($_)||'') eq 'HASH' &&
-      exists $_->{''} && exists $_->{-as} &&
-      scalar(keys %$_) == 2
-    ) ? $_->{''} : $_ } @$sels
+    @$sels = map { $self->_extract_hash_inner_AS($_) } @$sels
   }
   # -----
 
@@ -837,6 +839,18 @@ sub rs_all {
 }
 
 
+sub _is_special_AS_hash {
+  my ($self, $h) = @_;
+  (ref($h)||'') eq 'HASH' && exists $h->{''} && exists $h->{-as} &&  scalar(keys %$h) == 2
+}
+
+# extract the nested select ref from the special ''/-as structure
+sub _extract_hash_inner_AS {
+  my ($self, $select) = @_;
+  $self->_is_special_AS_hash($select) ? $select->{''} : $select
+}
+
+
 has '_count_col', is => 'ro', lazy => 1, default => sub {
   my $self = shift;
   
@@ -1449,7 +1463,7 @@ sub _resolve_quicksearch_condition {
   );
 
   my $dtype    = $cnf->{broad_data_type} || 'text';
-  my $dbicname = $self->resolve_dbic_colname($field,$join);
+  my $dbicname = $self->_extract_hash_inner_AS( $self->resolve_dbic_colname($field,$join) );
 
   # For numbers, force to 'exact' mode and discard (return undef) for queries
   # which are not numbers (since we already know they will not match anything). 
@@ -1479,8 +1493,8 @@ sub _resolve_quicksearch_condition {
 
   # 'text' is the only type which can do a LIKE (i.e. sub-string)
   return $mode eq 'like' 
-    ? { $dbicname => { $s->('like') => join('%','',$query,'') } }
-    : { $dbicname => { $s->('=')    => $query } };
+    ? $self->_op_fuse($dbicname => { $s->('like') => join('%','',$query,'') })
+    : $self->_op_fuse($dbicname => { $s->('=')    => $query });
 }
 
 
